summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/app/generated_resources.grd8
-rw-r--r--chrome/browser/about_flags.cc6
-rw-r--r--chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.cc4
-rw-r--r--chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.cc2
-rw-r--r--chrome/browser/ui/ash/launcher/launcher_context_menu.cc8
-rw-r--r--chrome/common/chrome_switches.cc4
-rw-r--r--chrome/common/chrome_switches.h2
7 files changed, 17 insertions, 17 deletions
diff --git a/chrome/app/generated_resources.grd b/chrome/app/generated_resources.grd
index 860e3bd..81d8d29 100644
--- a/chrome/app/generated_resources.grd
+++ b/chrome/app/generated_resources.grd
@@ -7173,11 +7173,11 @@ Keep your key file in a safe place. You will need it to create new versions of y
<message name="IDS_FLAGS_DOCKED_WINDOWS_DESCRIPTION" desc="Description for the flag to enable docked windows feature.">
Turns on docking of windows near screen edges, a feature that provides an easier way to interact with panel and other small windows.
</message>
- <message name="IDS_FLAGS_SHOW_LAUNCHER_ALIGNMENT_MENU_NAME" desc="Name for the flag to show a menu that lets you change the alignment of the launcher.">
- Show launcher alignment menu.
+ <message name="IDS_FLAGS_SHOW_SHELF_ALIGNMENT_MENU_NAME" desc="Name for the flag to show a menu that lets you change the alignment of the shelf.">
+ Show shelf alignment menu.
</message>
- <message name="IDS_FLAGS_SHOW_LAUNCHER_ALIGNMENT_MENU_DESCRIPTION" desc="Description for the flag to show a menu that lets you change the alignment of the launcher.">
- Enables a menu that allows changing the side the launcher is aligned to.
+ <message name="IDS_FLAGS_SHOW_SHELF_ALIGNMENT_MENU_DESCRIPTION" desc="Description for the flag to show a menu that lets you change the alignment of the shelf.">
+ Enables a menu that allows changing the side the shelf is aligned to.
</message>
<message name="IDS_FLAGS_FORCE_MAXIMIZE_MODE_NAME" desc="Name for the flag which forces the window manager to use maximized mode wherever possible.">
Always maximized mode
diff --git a/chrome/browser/about_flags.cc b/chrome/browser/about_flags.cc
index ef2a1cc..4df1f89 100644
--- a/chrome/browser/about_flags.cc
+++ b/chrome/browser/about_flags.cc
@@ -1014,10 +1014,10 @@ const Experiment kExperiments[] = {
#if defined(USE_ASH)
{
"show-launcher-alignment-menu",
- IDS_FLAGS_SHOW_LAUNCHER_ALIGNMENT_MENU_NAME,
- IDS_FLAGS_SHOW_LAUNCHER_ALIGNMENT_MENU_DESCRIPTION,
+ IDS_FLAGS_SHOW_SHELF_ALIGNMENT_MENU_NAME,
+ IDS_FLAGS_SHOW_SHELF_ALIGNMENT_MENU_DESCRIPTION,
kOsAll,
- SINGLE_VALUE_TYPE(switches::kShowLauncherAlignmentMenu)
+ SINGLE_VALUE_TYPE(switches::kShowShelfAlignmentMenu)
},
{
"disable-minimize-on-second-launcher-item-click",
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.cc b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.cc
index 1bdacb4..71b0881 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.cc
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_app.cc
@@ -1396,7 +1396,7 @@ void ChromeLauncherControllerPerApp::UpdateAppLaunchersFromPref() {
int max_index = model_->item_count();
// Using the alternate shelf layout the App Icon should be the first item in
// the list thus start adding items at slot 1 (instead of slot 0).
- if(ash::switches::UseAlternateShelfLayout()) {
+ if (ash::switches::UseAlternateShelfLayout()) {
++index;
++max_index;
}
@@ -1501,7 +1501,7 @@ void ChromeLauncherControllerPerApp::SetShelfAutoHideBehaviorFromPrefs() {
void ChromeLauncherControllerPerApp::SetShelfAlignmentFromPrefs() {
if (!CommandLine::ForCurrentProcess()->HasSwitch(
- switches::kShowLauncherAlignmentMenu))
+ switches::kShowShelfAlignmentMenu))
return;
ash::Shell::RootWindowList root_windows = ash::Shell::GetAllRootWindows();
diff --git a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.cc b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.cc
index abd2bf1..3c2360a 100644
--- a/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.cc
+++ b/chrome/browser/ui/ash/launcher/chrome_launcher_controller_per_browser.cc
@@ -1335,7 +1335,7 @@ void ChromeLauncherControllerPerBrowser::SetShelfAutoHideBehaviorFromPrefs() {
void ChromeLauncherControllerPerBrowser::SetShelfAlignmentFromPrefs() {
if (!CommandLine::ForCurrentProcess()->HasSwitch(
- switches::kShowLauncherAlignmentMenu))
+ switches::kShowShelfAlignmentMenu))
return;
ash::Shell::RootWindowList root_windows = ash::Shell::GetAllRootWindows();
diff --git a/chrome/browser/ui/ash/launcher/launcher_context_menu.cc b/chrome/browser/ui/ash/launcher/launcher_context_menu.cc
index c6fcd6c..1d28300 100644
--- a/chrome/browser/ui/ash/launcher/launcher_context_menu.cc
+++ b/chrome/browser/ui/ash/launcher/launcher_context_menu.cc
@@ -141,13 +141,13 @@ void LauncherContextMenu::Init() {
// fullscreen because it is confusing when the preference appears not to
// apply.
if (!IsFullScreenMode()) {
- AddCheckItemWithStringId(
- MENU_AUTO_HIDE, IDS_AURA_LAUNCHER_CONTEXT_MENU_AUTO_HIDE);
+ AddCheckItemWithStringId(MENU_AUTO_HIDE,
+ IDS_ASH_SHELF_CONTEXT_MENU_AUTO_HIDE);
}
if (CommandLine::ForCurrentProcess()->HasSwitch(
- switches::kShowLauncherAlignmentMenu)) {
+ switches::kShowShelfAlignmentMenu)) {
AddSubMenuWithStringId(MENU_ALIGNMENT_MENU,
- IDS_AURA_LAUNCHER_CONTEXT_MENU_POSITION,
+ IDS_ASH_SHELF_CONTEXT_MENU_POSITION,
&launcher_alignment_menu_);
}
#if defined(OS_CHROMEOS)
diff --git a/chrome/common/chrome_switches.h b/chrome/common/chrome_switches.h
index 9d23e89..5ce615a 100644
--- a/chrome/common/chrome_switches.h
+++ b/chrome/common/chrome_switches.h
@@ -338,7 +338,7 @@ extern const char kSilentLaunch[];
extern const char kSetToken[];
extern const char kShowAppList[];
extern const char kShowIcons[];
-extern const char kShowLauncherAlignmentMenu[];
+extern const char kShowShelfAlignmentMenu[];
extern const char kSigninProcess[];
extern const char kSilentDumpOnDCHECK[];
extern const char kSimulateUpgrade[];
diff --git a/chrome/common/chrome_switches.cc b/chrome/common/chrome_switches.cc
index 40e19dd..072d504 100644
--- a/chrome/common/chrome_switches.cc
+++ b/chrome/common/chrome_switches.cc
@@ -1257,8 +1257,8 @@ const char kShowAppList[] = "show-app-list";
// See kHideIcons.
const char kShowIcons[] = "show-icons";
-// If true the alignment of the launcher can be changed.
-const char kShowLauncherAlignmentMenu[] = "show-launcher-alignment-menu";
+// If true the alignment of the shelf can be changed.
+const char kShowShelfAlignmentMenu[] = "show-launcher-alignment-menu";
// Marks a renderer as the signin process.
const char kSigninProcess[] = "signin-process";